@@ -20,7 +20,7 @@ class SettingsLoader(object):
             ImportError: If it can't import the setting module.
         '''
         
-        if object != None:
+        if settings_module != None:
             module = importlib.import_module(settings_module)
             
             for setting in dir(module):
@@ -30,5 +30,5 @@ class SettingsLoader(object):
 #convenience attribute that knows how to initiate the settings class.
 try:
     settings = SettingsLoader(os.environ[ENVIRONMENT_VARIABLE])
-except ImportError:
+except KeyError:
     settings = SettingsLoader(None)
\ No newline at end of file
